{ config, lib, pkgs, jovian, ... }:
{
  imports = [ ./desktop ];

  config = lib.mkIf config.jovian.steam.enable {
    # Steam and Jovian services
    jovian = {
      steam = {
        autoStart = true;
        user = config.vars.mainUser;
      };
      decky-loader = {
        enable = true;
        package = pkgs.decky-loader-prerelease;
      };
      devices.steamdeck = {
        enable = true;
        enableGyroDsuService = true;
      };
    };

    # Disable NFS mounts
    boot.supportedFilesystems.nfs = lib.mkForce false;

    # Steam input on Wayland desktops
    programs.steam.extest.enable = true;

    # Xbox controller support
    hardware.xone.enable = true;

    # NetworkManager for UI compatibility
    networking.networkmanager.enable = true;

    # Disable conflicting services
    services = {
      keyd.enable = lib.mkForce false;
      tlp.enable = lib.mkForce false;
    };

    environment.persistence."/persist".directories = [
      "/etc/NetworkManager/system-connections"
      "/var/lib/decky-loader"
    ];

    nixpkgs.allowUnfreePackages = [
      "steam"
      "steam-jupiter-unwrapped"
      "steamdeck-firmware"
      "steamdeck-hw-theme"
      "xow_dongle-firmware"
    ];

    specialisation.desktop.configuration.config.jovian.steam.enable = lib.mkForce false;
  };
}
